# Changelog

## [unreleased]

## [1.0.0]

- Initial release.

## [1.0.0-beta0]

- Added `max_version` parameter.

- Improved detection of changes in VHS files.

- Delayed cleaning up old GIFs by `vhs_cleanup_delay`, 1 day by default.

- Plugin can now detect circular `Source` commands.

- Updated CI and dependencies.

[unreleased]: https://github.com/taminomara/sphinx-vhs/compare/v1.0.0...HEAD
[1.0.0]: https://github.com/taminomara/sphinx-vhs/compare/v1.0.0-beta0...v1.0.0
[1.0.0-beta0]: https://github.com/taminomara/sphinx-vhs/compare/v0.0.4...v1.0.0-beta0
